@@ -11,7 +11,7 @@ from redis.exceptions import ResponseError
 
 from .utils import LazySlicingIterable
 
-REDISBOARD_ITEMS_PER_PAGE = getattr(settings, 'REDISBOARD_ITEMS_PER_PAGE', 1000)
+REDISBOARD_ITEMS_PER_PAGE = getattr(settings, 'REDISBOARD_ITEMS_PER_PAGE', 200)
 
 def safeint(value):
     try:
@@ -51,7 +51,7 @@ def _get_key_info(conn, key):
             'length': "n/a",
             'name': key,
             'details': {},
-            'error': e,
+            'error': str(e),
             'ttl': "n/a",
         }
 
@@ -61,6 +61,7 @@ VALUE_GETTERS = {
     'set': lambda conn, key, *args: list(enumerate(conn.smembers(key))),
     'zset': lambda conn, key, start=0, end=-1: [(pos+start, val) for pos, val in enumerate(conn.zrange(key, start, end))],
     'hash': lambda conn, key, *args: conn.hgetall(key).items(),
+    'n/a': lambda conn, key, *args: (),
 }
 
 def _get_key_details(conn, db, key, page):
@@ -74,7 +75,7 @@ def _get_key_details(conn, db, key, page):
                 curry(VALUE_GETTERS[details['type']], conn, key)
             ),
             REDISBOARD_ITEMS_PER_PAGE
-        ).page(page)
+        ).page(page).object_list
     else:
         details['data'] = VALUE_GETTERS[details['type']](conn, key)
 
